==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridAnimationSettingsDescription } from "./GridAnimationSettingsDescription";
/**
 * @hidden
 */
var GridAnimationSettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridAnimationSettingsDescriptionMetadata, _super);
    function GridAnimationSettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridAnimationSettingsDescriptionMetadata.b = function (a) {
        if (GridAnimationSettingsDescriptionMetadata.a == null) {
            GridAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridAnimationSettingsDescriptionMetadata.c(GridAnimationSettingsDescriptionMetadata.a);
        }
        if (a.g(GridAnimationSettingsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridAnimationSettingsDescriptionMetadata.a);
    };
    GridAnimationSettingsDescriptionMetadata.c = function (a) {
    };
    GridAnimationSettingsDescriptionMetadata.d = function (a) {
        GridAnimationSettingsDescriptionMetadata.b(a);
        a.u("GridAnimationSettings", function () { return new GridAnimationSettingsDescription(); });
        a.t("GridAnimationSettings", GridAnimationSettingsDescriptionMetadata.a);
    };
    GridAnimationSettingsDescriptionMetadata.$t = markType(GridAnimationSettingsDescriptionMetadata, 'GridAnimationSettingsDescriptionMetadata');
    GridAnimationSettingsDescriptionMetadata.a = null;
    return GridAnimationSettingsDescriptionMetadata;
}(Base));
export { GridAnimationSettingsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridAnimationSettingsDescription } from "./GridAnimationSettingsDescription";
/**
 * @hidden
 */
var GridAnimationSettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridAnimationSettingsDescriptionMetadata, _super);
    function GridAnimationSettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridAnimationSettingsDescriptionMetadata.b = function (a) {
        if (GridAnimationSettingsDescriptionMetadata.a == null) {
            GridAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridAnimationSettingsDescriptionMetadata.c(GridAnimationSettingsDescriptionMetadata.a);
        }
        if (a.j(GridAnimationSettingsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridAnimationSettingsDescriptionMetadata.a);
    };
    GridAnimationSettingsDescriptionMetadata.c = function (a) {
    };
    GridAnimationSettingsDescriptionMetadata.d = function (a) {
        GridAnimationSettingsDescriptionMetadata.b(a);
        a.aa("GridAnimationSettings", function () { return new GridAnimationSettingsDescription(); });
        a.z("GridAnimationSettings", GridAnimationSettingsDescriptionMetadata.a);
    };
    GridAnimationSettingsDescriptionMetadata.$t = markType(GridAnimationSettingsDescriptionMetadata, 'GridAnimationSettingsDescriptionMetadata');
    GridAnimationSettingsDescriptionMetadata.a = null;
    return GridAnimationSettingsDescriptionMetadata;
}(Base));
export { GridAnimationSettingsDescriptionMetadata };
